@@ -200,6 +200,9 @@ class Connector:
         if 'device_id' in delivery_opts:
             data['device_id'] = delivery_opts['device_id']
 
+        if 'deliver_to' in delivery_opts:
+            data['deliver_to'] = delivery_opts['deliver_to']
+
         if 'device_id' not in data:
             data['device_id'] = self.device_id
 
@@ -213,6 +216,20 @@ class Connector:
 
         self.sio.emit(event, data)
 
+    def send_to(self, to: str, data: DataMsg, **delivery_opts):
+        '''
+        Emits a new_data event to another device_id group
+        Parameters
+        ----------
+        to : str
+            the device_id of the receiver
+
+        data : DataMsg
+            the data to send, fields 'time_stamp' and 'device_id' are added when they are not present
+        '''
+        data['deliver_to'] = to
+        self.emit(SocketEvents.NEW_DATA, data=data, **delivery_opts)
+
     def send(self, data: DataMsg, **delivery_opts):
         '''
         Emits a new_data event
@@ -2349,13 +2366,14 @@ class Connector:
 
         data['all_data'] = DictX(xdata)
         self.data[data['device_id']] = data['all_data']
-        # if DataType.SPRITES in data['all_data'] and data['device_id'] == self.device_id:
-        #     if self.__initial_all_data_received:
-        #         self.__sprites = list(map(lambda s: s['sprite'], data['all_data']['sprites']))
-        #     else:
-        #         for s in data['all_data']['sprites']:
-        #             if 'id' in s and self.get_sprite(s['id']) is None:
-        #                 self.__sprites.append(DictX(s))
+        if data['device_id'] == self.device_id:
+            if DataType.SPRITE in data['all_data']:
+                if self.__initial_all_data_received:
+                    self.__sprites = list(map(lambda s: DictX(s), data['all_data'][DataType.SPRITE]))
+                else:
+                    for s in data['all_data'][DataType.SPRITE]:
+                        if 'id' in s and self.get_sprite(s['id']) is None:
+                            self.__sprites.append(DictX(s))
 
         self.__initial_all_data_received = True
         self.__callback('on_all_data', data)
